@@ -1,4 +1,5 @@
 from pycid_dev.lib.attribute.constants import kInheritanceSourceTrait
+from pycid_dev.lib.attribute.attribute import Attribute
 
 
 def yes_or_no(question):
@@ -18,7 +19,7 @@ class Component(object):
     def __init__(self, client, raw_component):
         self.name = raw_component["name"]
         self.id = raw_component["id"]
-        self.attributes = raw_component["attributes"]
+        self._attributes = raw_component["attributes"]
         self.generic_component_ids = raw_component["template_ids"]
         self.crate_id = raw_component["crate_id"]
 
@@ -34,10 +35,23 @@ class Component(object):
         #               ) == sorted(self._network_callbacks.keys())
 
     def __repr__(self):
-        return f"Component({self.name}: {self.id}, {len(self.attributes)} attributes, {len(self.generic_component_ids)} generic components)"
+        return f"Component({self.name}: {self.id}, {len(self._attributes)} attributes, {len(self.generic_component_ids)} generic components)"
+
+    def rename(self, new_name):
+        result = self._client.rename_node(self.crate_id, self.id, new_name)
+        return {"edited": result["success"], "error": ""}
+
+    def attributes(self):
+        return [Attribute(self._client, self.crate_id, self.id, attr) for attr in self._attributes]
+
+    def get_attribute_by_id(self, attribute_id):
+        for attr in self._attributes:
+            if attr["id"] == attribute_id:
+                return Attribute(self._client, self.crate_id, self.id, attr)
+        return None
 
     def get_attribute_by_name(self, name, inheritance_source: str = None):
-        for attr in self.attributes:
+        for attr in self._attributes:
             if attr["name"] == name:
                 # If an inheritance_source was provided, check if it was inherited from
                 if (
@@ -46,7 +60,7 @@ class Component(object):
                 ):
                     continue
 
-                return attr
+                return Attribute(self._client, self.crate_id, self.id, attr)
         return None
 
     def has_attribute_by_name(self, name, inheritance_source: str = None):
@@ -77,7 +91,7 @@ class Component(object):
         """
         new_attribute_aux: tuple with a key and value for the aux
         """
-        attr = next(a for a in self.attributes if a["id"] == attribute_id)
+        attr = next(a for a in self._attributes if a["id"] == attribute_id)
         if not attr:
             return (
                 False,
@@ -119,7 +133,7 @@ class Component(object):
         return {"edited": result["success"], "error": ""}
 
     def remove_attribute_by_id(self, attribute_id, ignore_prompt=False):
-        if not any(attr["id"] == attribute_id for attr in self.attributes):
+        if not any(attr["id"] == attribute_id for attr in self._attributes):
             return (
                 False,
                 f'Could not find attribute in {self.name} with id "{attribute_id}"',
@@ -140,7 +154,7 @@ class Component(object):
         Simply remove an attribute from this component with a specific name
         """
         attribute_id = None
-        for attribute in self.attributes:
+        for attribute in self._attributes:
             if attribute["name"] == attribute_name:
                 attribute_id = attribute["id"]
                 break
